vector-text-core provides core primitives for the vector-text crate.
Structs
- Glyph
- A single glyph (character) contained within a font.
- Packed
Point - A point, in compact representation. Used to store the points which make up an individual glyph.
- Point
- Representation of a point with higher range than PackedPoint. Used for the output of text rendering.
Traits
- Renderer
- Allows rendering text into vector points.